############################################################################################################
##R script used in the data analyses for 
##
##CONTACT PERSON: Manuela Gonzalez Suarez, manuela.gonzalez.suarez@gmail.com
############################################################################################################

############################################################################################################
##Read data and define data subsets####
############################################################################################################

##phylogeny
library(caper)
library(phytools)
tree=read.nexus("Fritz_tree.nex") 

###diet and life-history data
data<- read.table("Olalla-Tarraga_et_al_Mammalian_Diet_Data.csv",sep=",", header=T )
names(data)
data$orders_analysis<-as.character(data$Order)
data$orders_analysis[data$SMALL_ORDERS==1] <- "Small_orders"
orders<-unique(data$orders_analysis)

MammalDIET_sub<-subset(data,MammalDIET==1)
EltonTraits_sub<-subset(data,EltonTraits==1)
CUFdiet_sub<-subset(data, CUFdiet==1)

############################################################################################################
########PHYLOGENETIC SIGNAL IN GENERAL QUANTITATIVE DIET DESCRIPTORS AND OTHER TRAITS################
############################################################################################################
##REPRODUCES RESULTS DISPLAY IN FIGURE 2 AND TABLE S1 (NOTE THAT BECAUSE P-VALUES ARE BASED ON SIMULATIONS AND RANDOMIZATIONS VALUES WILL CHANGE EACH TIME)

##Function K_P0_P1_function gives:
  ## empirical K value
  ## P0 is the P-value for the null hypothesis that there is no phylogenetic signal in the data based on a randomization test
  ## P1 is the P-value for the null hypothesis that K is consistent with a Brownian model of evolution based on simulations 

##Simulation approach is based on code provided by Liam Revell http://blog.phytools.org/2011/12/testing-for-phylogenetic-signal-k.html
##Using fastBM we can simulate the values of a trait along our phylogenetic tree if evolution followed a Brownian model with the value of the root taxa (parameter a) set to be the mean value of the trait in the observed data, the variance (sig2) set as the variance in the data. 
##to estimate these parameters from the data the tree needs to have no polytomies, so we apply a random break of the polytomies using the function multi2di from package ape to break polytomies 

##For each trait we set bounds to the minimum and maximum possible values:
  ##[1,12] for the diet breadth of MammalDIET and CUFdiet and [1,10] for EltonTraits, these bounds are defined by the food categories possible
  ##[0,Inf] for log10 of gestation length, assuming due to metabolic constrains gestation lenghts <1 day would not evolve. 
  ##[0,Inf] for log10 of adult body mass, assuming due to metabolic constrains mammals weighting <1 gr would not evolve. 
  ##[-Inf,Inf] for log10 of home range size, assuming home range size can take any value. 
  ##[0,Inf] for log10 of group size, group size <1 are not possible
  ##[0,Inf] for log10 of distribution range size, assuming species with global distribution areas <1 km2 would not evolve.
##P1 is calculated following Liam Revell's suggestion "that we do this by counting the number of times that the absolute value of the logarithm of our observed value for K is no smaller than the absolute values of our simulated values for K. This just makes K=1.5 & K=0.6667 equivalent departures from BM." 

K_P0_P1_function<-function(data_subset, trait, N_sim, bounds_sim, log=FALSE){
  if (log==FALSE){
    print("non-transformed variable")
    row.names(data_subset)=data_subset$binomial_tree
    test1=as.vector(as.matrix(subset(data_subset, select=trait)))
    names(test1)=row.names(data_subset)
    kappa<-phylosig(tree, test1, method="K",test=T) 
    sss<-which(names(data_subset)==trait)
    selection<-subset(data_subset, data_subset[,sss]>0)
    tree1 <- multi2di(tree, random = TRUE)  
    C1 <- comparative.data(phy = tree1, data = selection, names.col = binomial_tree, warn.dropped = FALSE, na.omit=F)
    ss<-which(names(C1$data)==trait)
    nullK<-apply(fastBM(C1$phy, n=N_sim, sig2=mean(pic(C1$data[,ss],C1$phy)^2), a=mean(C1$data[,ss]), bounds=bounds_sim),2, phylosig,tree=C1$phy)
    p1_value<-mean(abs(log(c(kappa$K,nullK)))>=abs(log(kappa$K)))
    return(list(trait, length(na.omit(C1$data[,ss])),round(kappa$K, digits=2),round(kappa$P, digits=3),round(p1_value, digits=3)))
  }
  else {
    print("log-transformed variable")
    row.names(data_subset)=data_subset$binomial_tree
    test1=as.vector(as.matrix(subset(data_subset, select=trait)))
    test1=log10(test1)
    names(test1)=row.names(data_subset)
    kappa<-phylosig(tree, test1, method="K",test=T) 
    sss<-which(names(data)==trait)
    selection<-subset(data_subset, data_subset[,sss]>0)
    tree1 <- multi2di(tree, random = TRUE)
    C1 <- comparative.data(phy = tree1, data = selection, names.col = binomial_tree, warn.dropped = FALSE, na.omit=F)
    ss<-which(names(C1$data)==trait)
    nullK<-apply(fastBM(C1$phy, n=N_sim, sig2=mean(pic(log10(C1$data[,ss]),C1$phy)^2), a=mean(log10(C1$data[,ss])), bounds=bounds_sim),2, phylosig,tree=C1$phy)
    p1_value<-mean(abs(log(c(kappa$K,nullK)))>=abs(log(kappa$K)))
    return(list(trait, length(na.omit(C1$data[,ss])),round(kappa$K, digits=2),round(kappa$P, digits=3),round(p1_value, digits=3)))
  }
}

MD_diet<-K_P0_P1_function(MammalDIET_sub,"MD_Diet_breadth", 1000, c(1,12))
MD_ges<-K_P0_P1_function(MammalDIET_sub,"Gestation_length_days", 1000, c(-Inf,Inf), log=TRUE)
MD_mass<-K_P0_P1_function(MammalDIET_sub,"Adult_body_mass_g", 1000, c(-Inf,Inf), log=TRUE)
MD_home<-K_P0_P1_function(MammalDIET_sub,"Home_range_size_km2", 1000, c(-Inf,Inf), log=TRUE)
MD_group<-K_P0_P1_function(MammalDIET_sub,"Group_size_ind", 1000, c(-Inf,Inf), log=TRUE)
MD_dist<-K_P0_P1_function(MammalDIET_sub,"Distribution_range_area_km2", 1000, c(-Inf,Inf), log=TRUE)

MD_results<-rbind(MD_ges, MD_mass, MD_home, MD_group, MD_dist,MD_diet,c("NA", "NA", "NA", "NA", "NA"))

ET_diet<-K_P0_P1_function(EltonTraits_sub,"ET_Diet_breadth", 1000, c(1,10))
ET_Levins<-K_P0_P1_function(EltonTraits_sub,"ET_Levins_stand", 1000, c(0,1))
ET_ges<-K_P0_P1_function(EltonTraits_sub,"Gestation_length_days", 1000, c(0,Inf), log=TRUE)
ET_mass<-K_P0_P1_function(EltonTraits_sub,"Adult_body_mass_g", 1000, c(0,Inf), log=TRUE)
ET_home<-K_P0_P1_function(EltonTraits_sub,"Home_range_size_km2", 1000, c(-Inf,Inf), log=TRUE)
ET_group<-K_P0_P1_function(EltonTraits_sub,"Group_size_ind", 1000, c(0,Inf), log=TRUE)
ET_dist<-K_P0_P1_function(EltonTraits_sub,"Distribution_range_area_km2", 1000, c(0,Inf), log=TRUE)

ET_results<-rbind(ET_ges, ET_mass, ET_home, ET_group, ET_dist,ET_diet, ET_Levins)

CUF_diet<-K_P0_P1_function(CUFdiet_sub,"CUF_Diet_breadth", 1000, c(1,12))
CUF_Levins<-K_P0_P1_function(CUFdiet_sub,"CUF_Levins_stand", 1000, c(0,1))
CUF_ges<-K_P0_P1_function(CUFdiet_sub,"Gestation_length_days", 1000, c(0,Inf), log=TRUE)
CUF_mass<-K_P0_P1_function(CUFdiet_sub,"Adult_body_mass_g", 1000, c(0,Inf), log=TRUE)
CUF_home<-K_P0_P1_function(CUFdiet_sub,"Home_range_size_km2", 1000, c(-Inf,Inf), log=TRUE)
CUF_group<-K_P0_P1_function(CUFdiet_sub,"Group_size_ind", 1000, c(0,Inf), log=TRUE)
CUF_dist<-K_P0_P1_function(CUFdiet_sub,"Distribution_range_area_km2", 1000, c(0,Inf), log=TRUE)

CUF_results<-rbind(CUF_ges, CUF_mass, CUF_home, CUF_group, CUF_dist,CUF_diet, CUF_Levins)

##generating results for table S1
Table_S1_results<-cbind(c("Gestation_length_days", "Adult_body_mass_g","Home_range_size_km2", "Group_size_ind", "Distribution_range_area_km2", "Diet_breadth", "Levin's index"),MD_results[,-1],ET_results[,-1],CUF_results[,-1])
colnames(Table_S1_results)<-c("Variable","MD_sample_size", "MD_K", "MD_P0", "MD_P1","ET_sample_size", "ET_K", "ET_P0", "ET_P1","CUF_sample_size", "CUF_K", "CUF_P0", "CUF_P1")

############################################################################################################
########PHYLOGENETIC SIGNAL IN DIET BREADTH FOR DISTINCT MAMMALIAN ORDERS################
############################################################################################################
##REPRODUCES RESULTS FOR TABLE 1
##Please note that there is no data on MammalDIET for Cetacea
results_orders<-list()

for (i in 1:length(orders)){
  j<-noquote(toString(orders[i]))
  if (j!="Cetacea"){
    sub<-subset(MammalDIET_sub, orders_analysis==j)
    compData_MD <- comparative.data(phy = tree, data = sub, names.col = binomial_tree, warn.dropped = FALSE, na.omit=F)
    test1=as.vector(as.matrix(subset(compData_MD$data, select=MD_Diet_breadth)))
    names(test1)=compData_MD$phy$tip.label
    kappa_MD<-phylosig(tree, test1, method="K",test=T) 
    compData_MD1 <- comparative.data(phy = tree1, data = sub, names.col = binomial_tree, warn.dropped = F, na.omit=F)
    nullK_MD<-apply(fastBM(compData_MD1$phy, n=N_simulations, sig2=mean(pic(compData_MD1$data$MD_Diet_breadth,compData_MD1$phy)^2), a=mean(compData_MD1$data$MD_Diet_breadth), bounds=c(1,12)),2, phylosig,tree=compData_MD1$phy)
    
    sub1<-subset(EltonTraits_sub, orders_analysis==j)
    compData_ET<- comparative.data(phy = tree, data = sub1, names.col = binomial_tree, warn.dropped = FALSE, na.omit=F)
    test2=as.vector(as.matrix(subset(compData_ET$data, select=ET_Diet_breadth)))
    names(test2)=compData_ET$phy$tip.label
    kappa_ET<-phylosig(tree, test2, method="K",test=T) 
    compData_ET1 <- comparative.data(phy = tree1, data = sub1, names.col = binomial_tree, warn.dropped = F, na.omit=F)
    nullK_ET<-apply(fastBM(compData_ET1$phy, n=N_simulations, sig2=mean(pic(compData_ET1$data$ET_Diet_breadth,compData_ET1$phy)^2), a=mean(compData_ET1$data$ET_Diet_breadth), bounds=c(1,10)),2, phylosig,tree=compData_ET1$phy)
    
    results_orders[[j]]<-c(j,
                           nrow(compData_MD$data),
                           round(kappa_MD$K, digits=2), 
                           round(kappa_MD$P, digits=3), 
                           round(mean(abs(log(c(kappa_MD$K,nullK_MD)))>=abs(log(kappa_MD$K))), digits=3),
                           round(mean(compData_MD$data$MD_Diet_breadth, na.rm=T), digits=2),
                           round(sd(compData_MD$data$MD_Diet_breadth, na.rm=T), digits=3),
                           nrow(compData_ET$data),
                           round(kappa_ET$K, digits=2), 
                           round(kappa_ET$P, digits=3),
                           round(mean(abs(log(c(kappa_ET$K,nullK_ET)))>=abs(log(kappa_ET$K))), digits=3),
                           round(mean(compData_ET$data$ET_Diet_breadth, na.rm=T), digits=2),
                           round(sd(compData_ET$data$ET_Diet_breadth, na.rm=T), digits=3))
  }
  else{
    sub1<-subset(EltonTraits_sub, Order==j)
    compData_ET<- comparative.data(phy = tree, data = sub1, names.col = binomial_tree, warn.dropped = FALSE, na.omit=F)
    test2=as.vector(as.matrix(subset(compData_ET$data, select=ET_Diet_breadth)))
    names(test2)=compData_ET$phy$tip.label
    kappa_ET<-phylosig(tree, test2, method="K",test=T) 
    compData_ET1 <- comparative.data(phy = tree1, data = sub1, names.col = binomial_tree, warn.dropped = F, na.omit=F)
    nullK_ET<-apply(fastBM(compData_ET1$phy, n=N_simulations, sig2=mean(pic(compData_ET1$data$ET_Diet_breadth,compData_ET1$phy)^2), a=mean(compData_ET1$data$ET_Diet_breadth), bounds=c(1,10)),2, phylosig,tree=compData_ET1$phy)
    
    results_orders[[j]]<-c(j,"NA","NA", "NA","NA","NA","NA",
                           nrow(compData_ET$data),
                           round(kappa_ET$K, digits=2), 
                           round(kappa_ET$P, digits=3),
                           round(mean(abs(log(c(kappa_ET$K,nullK_ET)))>=abs(log(kappa_ET$K))), digits=3),
                           round(mean(compData_ET$data$ET_Diet_breadth, na.rm=T), digits=2),
                           round(sd(compData_ET$data$ET_Diet_breadth, na.rm=T), digits=3))
  }
}

##REPRODUCES RESULTS FOR FIGURE 3 TABLE S3
##Signal for species with data on both MammalDIET and EltonTraits####

shared_sub<-subset(data, MammalDIET==1 & EltonTraits==1)
orders_shared<-orders[-9] ##remove Cetacea from the list as no Cetacea species are described in MammalDIET

results_orders_shared<-list()

for (i in 1:length(orders_shared)){
  
  j<-noquote(toString(orders_shared[i]))
  
  sub<-subset(shared_sub, orders_analysis==j)
  compData_MD <- comparative.data(phy = tree, data = sub, names.col = binomial_tree, warn.dropped = FALSE, na.omit=F)
  test1=as.vector(as.matrix(subset(compData_MD$data, select=MD_Diet_breadth)))
  names(test1)=compData_MD$phy$tip.label
  kappa_MD<-phylosig(tree, test1, method="K",test=T) 
  compData_MD1 <- comparative.data(phy = tree1, data = sub, names.col = binomial_tree, warn.dropped = F, na.omit=F)
  nullK_MD<-apply(fastBM(compData_MD1$phy, n=N_simulations, sig2=mean(pic(compData_MD1$data$MD_Diet_breadth,compData_MD1$phy)^2), a=mean(compData_MD1$data$MD_Diet_breadth), bounds=c(1,12)),2, phylosig,tree=compData_MD1$phy)
  
  sub1<-subset(shared_sub, orders_analysis==j)
  compData_ET<- comparative.data(phy = tree, data = sub1, names.col = binomial_tree, warn.dropped = FALSE, na.omit=F)
  test2=as.vector(as.matrix(subset(compData_ET$data, select=ET_Diet_breadth)))
  names(test2)=compData_ET$phy$tip.label
  kappa_ET<-phylosig(tree, test2, method="K",test=T) 
  
  compData_ET1 <- comparative.data(phy = tree1, data = sub1, names.col = binomial_tree, warn.dropped = F, na.omit=F)
  nullK_ET<-apply(fastBM(compData_ET1$phy, n=N_simulations, sig2=mean(pic(compData_ET1$data$ET_Diet_breadth,compData_ET1$phy)^2), a=mean(compData_ET1$data$ET_Diet_breadth), bounds=c(1,10)),2, phylosig,tree=compData_ET1$phy)
  
  results_orders_shared[[j]]<-c(j,
                                nrow(compData_MD$data),
                                round(kappa_MD$K, digits=2), 
                                round(kappa_MD$P, digits=3), 
                                round(mean(abs(log(c(kappa_MD$K,nullK_MD)))>=abs(log(kappa_MD$K))), digits=3), 
                                round(kappa_ET$K, digits=2), 
                                round(kappa_ET$P, digits=3), 
                                round(mean(abs(log(c(kappa_ET$K,nullK_ET)))>=abs(log(kappa_ET$K))), digits=3))
}

############################################################################################################
########PHYLOGENETIC SIGNAL IN BINARY PRESENCE DATA FOR DIFFERENT DIET CATEGORIES################
############################################################################################################
##REPRODUCES RESULTS FOR FIGURE 4 AND TABLE S4. P-VALUES ARE BASED ON PERMUTATION TEST AND COULD CHANGE EACH TIME

N_permutations<-5000 ##defining the number of permutations to estimate P-values for D
compData_MD <- comparative.data(phy = tree, data = MammalDIET_sub, names.col = binomial_tree, warn.dropped = TRUE, na.omit=F)
dim(compData_MD$data)
compData_ET <- comparative.data(phy = tree, data = EltonTraits_sub, names.col = binomial_tree, warn.dropped = TRUE, na.omit=F)
dim(compData_ET$data)
compData_CUF <- comparative.data(phy = tree, data = CUFdiet_sub, names.col = binomial_tree, warn.dropped = TRUE, na.omit=F)
dim(compData_CUF$data)

##unclassified vertebrates is only a category in EltonTraits
ET_PhyloDvert_unc <- phylo.d(compData_ET, binvar=ET_vert_unclassified, permut = N_permutations)
vert_unc<-list("NA", "NA", "NA","NA",
               sum(EltonTraits_sub$ET_vert_unclassified), round(ET_PhyloDvert_unc$DEstimate,digits=2), round(ET_PhyloDvert_unc$Pval1, digits=3), round(ET_PhyloDvert_unc$Pval0, digits=3),
               "NA", "NA", "NA","NA")

##Endotherm vertebrates (mammals and birds). In CUFdiet all species have presence for this category and those D cannot be estimated 
MD_PhyloDvend <- phylo.d(compData_MD, binvar=MD_vend, permut = N_permutations)
ET_PhyloDvend <- phylo.d(compData_ET, binvar=ET_vend, permut = N_permutations)
vend<-list(sum(MammalDIET_sub$MD_vend), round(MD_PhyloDvend$DEstimate,digits=2), round(MD_PhyloDvend$Pval1, digits=3), round(MD_PhyloDvend$Pval0, digits=3),
              sum(EltonTraits_sub$ET_vend), round(ET_PhyloDvend$DEstimate,digits=2), round(ET_PhyloDvend$Pval1, digits=3), round(ET_PhyloDvend$Pval0, digits=3),
              "NA", "NA", "NA", "NA")

##Mammal category is only described in MammalDiet and CUFdiet
MD_PhyloDmammal <- phylo.d(compData_MD, binvar=MD_mammal, permut = N_permutations)
CUF_PhyloDmammal <- phylo.d(compData_CUF, binvar=CUF_mammal, permut = N_permutations)
mammal<-list(sum(MammalDIET_sub$MD_mammal), round(MD_PhyloDmammal$DEstimate,digits=2), round(MD_PhyloDmammal$Pval1, digits=3), round(MD_PhyloDmammal$Pval0, digits=3),
             "NA", "NA", "NA", "NA",
             sum(CUFdiet_sub$CUF_mammal), round(CUF_PhyloDmammal$DEstimate,digits=2), round(CUF_PhyloDmammal$Pval1, digits=3), round(CUF_PhyloDmammal$Pval0, digits=3))

##Bird category is only described in MammalDiet and CUFdiet
MD_PhyloDbird <- phylo.d(compData_MD, binvar=MD_bird, permut = N_permutations)
CUF_PhyloDbird <- phylo.d(compData_CUF, binvar=CUF_bird, permut = N_permutations)
bird<-list(sum(MammalDIET_sub$MD_bird), round(MD_PhyloDbird$DEstimate,digits=2), round(MD_PhyloDbird$Pval1, digits=3), round(MD_PhyloDbird$Pval0, digits=3),
           "NA", "NA", "NA","NA",
           sum(CUFdiet_sub$CUF_bird), round(CUF_PhyloDbird$DEstimate,digits=2), round(CUF_PhyloDbird$Pval1, digits=3), round(CUF_PhyloDbird$Pval0, digits=3))

MD_PhyloDherptile <- phylo.d(compData_MD, binvar=MD_herptile, permut = N_permutations)
ET_PhyloDherptile <- phylo.d(compData_ET, binvar=ET_herptile, permut = N_permutations)
CUF_PhyloDherptile <- phylo.d(compData_CUF, binvar=CUF_herptile, permut = N_permutations)
herptile<-list(sum(MammalDIET_sub$MD_herptile), round(MD_PhyloDherptile$DEstimate,digits=2), round(MD_PhyloDherptile$Pval1, digits=3), round(MD_PhyloDherptile$Pval0, digits=3),
               sum(EltonTraits_sub$ET_herptile), round(ET_PhyloDherptile$DEstimate,digits=2), round(ET_PhyloDherptile$Pval1, digits=3), round(ET_PhyloDherptile$Pval0, digits=3),
               sum(CUFdiet_sub$CUF_herptile), round(CUF_PhyloDherptile$DEstimate,digits=2), round(CUF_PhyloDherptile$Pval1, digits=3), round(CUF_PhyloDherptile$Pval0, digits=3))

MD_PhyloDfish <- phylo.d(compData_MD, binvar=MD_fish, permut = N_permutations)
ET_PhyloDfish <- phylo.d(compData_ET, binvar=ET_fish, permut = N_permutations)
CUF_PhyloDfish <- phylo.d(compData_CUF, binvar=CUF_fish, permut = N_permutations)
fish<-list(sum(MammalDIET_sub$MD_fish), round(MD_PhyloDfish$DEstimate,digits=2), round(MD_PhyloDfish$Pval1, digits=3), round(MD_PhyloDfish$Pval0, digits=3),
           sum(EltonTraits_sub$ET_fish), round(ET_PhyloDfish$DEstimate,digits=2), round(ET_PhyloDfish$Pval1, digits=3), round(ET_PhyloDfish$Pval0, digits=3),
           sum(CUFdiet_sub$CUF_fish), round(CUF_PhyloDfish$DEstimate,digits=2), round(CUF_PhyloDfish$Pval1, digits=3), round(CUF_PhyloDfish$Pval0, digits=3))

MD_PhyloDinvertebrate <- phylo.d(compData_MD, binvar=MD_invertebrate, permut = N_permutations)
ET_PhyloDinvertebrate <- phylo.d(compData_ET, binvar=ET_invertebrate, permut = N_permutations)
CUF_PhyloDinvertebrate <- phylo.d(compData_CUF, binvar=CUF_invertebrate, permut = N_permutations)
invertebrate<-list(sum(MammalDIET_sub$MD_invertebrate), round(MD_PhyloDinvertebrate$DEstimate,digits=2), round(MD_PhyloDinvertebrate$Pval1, digits=3), round(MD_PhyloDinvertebrate$Pval0, digits=3),
                   sum(EltonTraits_sub$ET_invertebrate), round(ET_PhyloDinvertebrate$DEstimate,digits=2), round(ET_PhyloDinvertebrate$Pval1, digits=3), round(ET_PhyloDinvertebrate$Pval0, digits=3),
                   sum(CUFdiet_sub$CUF_invertebrate), round(CUF_PhyloDinvertebrate$DEstimate,digits=2), round(CUF_PhyloDinvertebrate$Pval1, digits=3), round(CUF_PhyloDinvertebrate$Pval0, digits=3))

MD_PhyloDfruit <- phylo.d(compData_MD, binvar=MD_fruit, permut = N_permutations)
ET_PhyloDfruit <- phylo.d(compData_ET, binvar=ET_fruit, permut = N_permutations)
CUF_PhyloDfruit <- phylo.d(compData_CUF, binvar=CUF_fruit, permut = N_permutations)
fruit<-list(sum(MammalDIET_sub$MD_fruit), round(MD_PhyloDfruit$DEstimate,digits=2), round(MD_PhyloDfruit$Pval1, digits=3), round(MD_PhyloDfruit$Pval0, digits=3),
            sum(EltonTraits_sub$ET_fruit), round(ET_PhyloDfruit$DEstimate,digits=2), round(ET_PhyloDfruit$Pval1, digits=3), round(ET_PhyloDfruit$Pval0, digits=3),
            sum(CUFdiet_sub$CUF_fruit), round(CUF_PhyloDfruit$DEstimate,digits=2), round(CUF_PhyloDfruit$Pval1, digits=3), round(CUF_PhyloDfruit$Pval0, digits=3))

MD_PhyloDnectar <- phylo.d(compData_MD, binvar=MD_nectar, permut = N_permutations)
ET_PhyloDnectar <- phylo.d(compData_ET, binvar=ET_nectar, permut = N_permutations)
CUF_PhyloDnectar <- phylo.d(compData_CUF, binvar=CUF_nectar, permut = N_permutations)
nectar<-list(sum(MammalDIET_sub$MD_nectar), round(MD_PhyloDnectar$DEstimate,digits=2), round(MD_PhyloDnectar$Pval1, digits=3), round(MD_PhyloDnectar$Pval0, digits=3),
             sum(EltonTraits_sub$ET_nectar), round(ET_PhyloDnectar$DEstimate,digits=2), round(ET_PhyloDnectar$Pval1, digits=3), round(ET_PhyloDnectar$Pval0, digits=3),
             sum(CUFdiet_sub$CUF_nectar), round(CUF_PhyloDnectar$DEstimate,digits=2), round(CUF_PhyloDnectar$Pval1, digits=3), round(CUF_PhyloDnectar$Pval0, digits=3))

##Woody category is only described in MammalDiet and CUFdiet
MD_PhyloDwoody <- phylo.d(compData_MD, binvar=MD_woody, permut = N_permutations)
CUF_PhyloDwoody <- phylo.d(compData_CUF, binvar=CUF_woody, permut = N_permutations)
woody<-list(sum(MammalDIET_sub$MD_woody), round(MD_PhyloDwoody$DEstimate,digits=2), round(MD_PhyloDwoody$Pval1, digits=3), round(MD_PhyloDwoody$Pval0, digits=3),
            "NA", "NA", "NA","NA",
            sum(CUFdiet_sub$CUF_woody), round(CUF_PhyloDwoody$DEstimate,digits=2), round(CUF_PhyloDwoody$Pval1, digits=3), round(CUF_PhyloDwoody$Pval0, digits=3))

##Grass category is only described in MammalDiet and CUFdiet
MD_PhyloDgrass <- phylo.d(compData_MD, binvar=MD_grass, permut = N_permutations)
CUF_PhyloDgrass <- phylo.d(compData_CUF, binvar=CUF_grass, permut = N_permutations)
grass<-list(sum(MammalDIET_sub$MD_grass), round(MD_PhyloDgrass$DEstimate,digits=2), round(MD_PhyloDgrass$Pval1, digits=3), round(MD_PhyloDgrass$Pval0, digits=3),
            "NA", "NA", "NA","NA",
            sum(CUFdiet_sub$CUF_grass), round(CUF_PhyloDgrass$DEstimate,digits=2), round(CUF_PhyloDgrass$Pval1, digits=3), round(CUF_PhyloDgrass$Pval0, digits=3))

MD_PhyloDseed <- phylo.d(compData_MD, binvar=MD_seed, permut = N_permutations)
ET_PhyloDseed <- phylo.d(compData_ET, binvar=ET_seed, permut = N_permutations)
CUF_PhyloDseed <- phylo.d(compData_CUF, binvar=CUF_seed, permut = N_permutations)
seed<-list(sum(MammalDIET_sub$MD_seed), round(MD_PhyloDseed$DEstimate,digits=2), round(MD_PhyloDseed$Pval1, digits=3), round(MD_PhyloDseed$Pval0, digits=3),
           sum(EltonTraits_sub$ET_seed), round(ET_PhyloDseed$DEstimate,digits=2), round(ET_PhyloDseed$Pval1, digits=3), round(ET_PhyloDseed$Pval0, digits=3),
           sum(CUFdiet_sub$CUF_seed), round(CUF_PhyloDseed$DEstimate,digits=2), round(CUF_PhyloDseed$Pval1, digits=3), round(CUF_PhyloDseed$Pval0, digits=3))

##root category is only described in MammalDiet and CUFdiet, but in CUFdiet no species are listed as consuming roots
MD_PhyloDroot <- phylo.d(compData_MD, binvar=MD_root, permut = N_permutations)
root<-list(sum(MammalDIET_sub$MD_root), round(MD_PhyloDroot$DEstimate,digits=2), round(MD_PhyloDroot$Pval1, digits=3), round(MD_PhyloDroot$Pval0, digits=3),
           "NA", "NA", "NA", "NA",
           "NA", "NA", "NA", "NA")

##plant unclassified category is only described in EltonTraits
ET_PhyloDplant_unc <- phylo.d(compData_ET, binvar=ET_plant_unclassified, permut = N_permutations)
plant_unc<-list("NA", "NA", "NA", "NA",
                sum(EltonTraits_sub$ET_plant_unclassified), round(ET_PhyloDplant_unc$DEstimate,digits=2), round(ET_PhyloDplant_unc$Pval1, digits=3), round(ET_PhyloDplant_unc$Pval0, digits=3),
                "NA", "NA", "NA", "NA")

##carrion category is only described in EltonTraits and CUFdiet
ET_PhyloDcarrion <- phylo.d(compData_ET, binvar=ET_carrion, permut = N_permutations)
CUF_PhyloDcarrion <- phylo.d(compData_CUF, binvar=CUF_carrion, permut = N_permutations)
carrion<-list("NA", "NA", "NA","NA",
              sum(EltonTraits_sub$ET_carrion), round(ET_PhyloDcarrion$DEstimate,digits=2), round(ET_PhyloDcarrion$Pval1, digits=3), round(ET_PhyloDcarrion$Pval0, digits=3),
              sum(CUFdiet_sub$CUF_carrion), round(CUF_PhyloDcarrion$DEstimate,digits=2), round(CUF_PhyloDcarrion$Pval1, digits=3), round(CUF_PhyloDcarrion$Pval0, digits=3))

##Other category is only described in MammalDiet 
MD_PhyloDother <- phylo.d(compData_MD, binvar=MD_other, permut = N_permutations)
other<-list(sum(MammalDIET_sub$MD_other), round(MD_PhyloDother$DEstimate,digits=2), round(MD_PhyloDother$Pval1, digits=3), round(MD_PhyloDother$Pval0, digits=3),
            "NA", "NA", "NA","NA",
            "NA", "NA", "NA","NA")

##generating results for table S3 
table_PhyloD<- rbind(vert_unc,vend, mammal, bird, herptile, fish, invertebrate, fruit, nectar, woody, grass,  seed, root, plant_unc, carrion, other)
row.names(table_PhyloD)<-c("vert_unclassified","vend","mammal", "bird", "herptile", "fish", "invertebrate", "fruit","nectar","woody", "grass", "seed",  "root","plant_unclassified","carrion",  "other")
colnames(table_PhyloD)<-c("Np_MammalDiet","D_MammalDiet","P1_MammalDiet","P0_MammalDiet","Np_EltonTraits","D_EltonTraits","P1_EltonTraits","P0_EltonTraits","Np_CUFdiet","D_CUFdiet","P1_CUFdiet","P0_CUFdiet")


############################################################################################################
########PHYLOGENETIC SIGNAL IN QUANTITATIVE DATA FOR DIFFERENT DIET CATEGORIES################
############################################################################################################
##REPRODUCES RESULTS FOR TABLE 2
##uses function K_P0_P1_function defined in lines 43-75

MD_Mammal_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Mammal_quant", 2, c(1,4))
MD_Bird_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Bird_quant", 2, c(1,4))
MD_Herptile_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Herptile_quant", 2, c(1,4))
MD_Fish_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Fish_quant", 2, c(1,4))
MD_Invertebrate_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Invertebrate_quant", 2, c(1,4))
MD_Fruit_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Fruit_quant", 2, c(1,4))
MD_Nectar_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Nectar_quant", 2, c(1,4))
MD_Woody_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Woody_quant", 2, c(1,4))
MD_Grass_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Grass_quant", 2, c(1,4))
MD_Seed_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Seed_quant", 2, c(1,4))
MD_Root_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Root_quant", 2, c(1,4))
MD_Other_quant_K<-K_P0_P1_function(MammalDIET_sub,"MD_Other_quant", 2, c(1,4))

ET_Vert_uncl_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Vert_uncl_quant", 2, c(0,100))
ET_Vend_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Vend_quant", 2, c(0,100))
ET_Herptile_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Herptile_quant", 2, c(0,100))
ET_Fish_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Fish_quant", 2, c(0,100))
ET_Invertebrate_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Invertebrate_quant", 2, c(0,100))
ET_Fruit_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Fruit_quant", 2, c(0,100))
ET_Nectar_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Nectar_quant", 2, c(0,100))
ET_Seed_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Seed_quant", 2, c(0,100))
ET_Plant_unc_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Plant_unc_quant", 2, c(0,100))
ET_Carrion_quant_K<-K_P0_P1_function(EltonTraits_sub,"ET_Carrion_quant", 2, c(0,100))

CUF_Vend_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Vend_num_freq", 2, c(0,1))
CUF_Mammal_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Mammal_num_freq", 2, c(0,1))
CUF_Bird_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Bird_num_freq", 2, c(0,1))
CUF_Herptile_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Herptile_num_freq", 2, c(0,1))
CUF_Fish_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Fish_num_freq", 2, c(0,1))
CUF_Invertebrate_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Invertebrate_num_freq", 2, c(0,1))
CUF_Fruit_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Fruit_num_freq", 2, c(0,1))
CUF_Nectar_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Nectar_num_freq", 2, c(0,1))
CUF_Woody_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Woody_num_freq", 2, c(0,1))
CUF_Grass_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Grass_num_freq", 2, c(0,1))
CUF_Seed_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Seed_num_freq", 2, c(0,1))
CUF_Carrion_num_freq_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Carrion_num_freq", 2, c(0,1))

CUF_Mammal_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Mammal_freq_occu", 2, c(0,1))
CUF_Bird_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Bird_freq_occu", 2, c(0,1))
CUF_Herptile_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Herptile_freq_occu", 2, c(0,1))
CUF_Fish_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Fish_freq_occu", 2, c(0,1))
CUF_Invertebrate_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Invertebrate_freq_occu", 2, c(0,1))
CUF_Fruit_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Fruit_freq_occu", 2, c(0,1))
CUF_Woody_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Woody_freq_occu", 2, c(0,1))
CUF_Grass_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Grass_freq_occu", 2, c(0,1))
CUF_Seed_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Seed_freq_occu", 2, c(0,1))
CUF_Carrion_freq_occu_K<-K_P0_P1_function(CUFdiet_sub,"CUF_Carrion_freq_occu", 2, c(0,1))


##generating table results
Table_2_results<-rbind(list("Vert_uncl","NA","NA", "NA", "NA",ET_Vert_uncl_quant_K,"NA","NA", "NA", "NA","NA","NA", "NA", "NA"), 
                       list("Vend", "NA","NA", "NA", "NA", ET_Vend_quant_K,CUF_Vend_quant_K, "NA","NA", "NA", "NA"),
                       list("Mammal", MD_Mammal_quant_K, "NA","NA", "NA", "NA",CUF_Mammal_num_freq_K, CUF_Mammal_freq_occu_K),
                       list("Bird", MD_Bird_quant_K,"NA","NA", "NA", "NA",CUF_Bird_num_freq_K, CUF_Bird_freq_occu_K ),
                       list("Herptile", MD_Herptile_quant_K, ET_Herptile_quant_K, CUF_Herptile_num_freq_K, CUF_Herptile_freq_occu_K),
                       list("Fish", MD_Fish_quant_K, ET_Fish_quant_K, CUF_Fish_num_freq_K, CUF_Fish_freq_occu_K),
                       list("Invertebrate", MD_Invertebrate_quant_K, ET_Invertebrate_quant_K, CUF_Invertebrate_num_freq_K, CUF_Invertebrate_freq_occu_K),
                       list("Fruit", MD_Fruit_quant_K, ET_Fruit_quant_K, CUF_Fruit_num_freq_K, CUF_Fruit_freq_occu_K),
                       list("Nectar", MD_Nectar_quant_K, ET_Nectar_quant_K, CUF_Nectar_num_freq_K,"NA","NA", "NA", "NA"),
                       list("Woody", MD_Woody_quant_K,"NA","NA", "NA", "NA",CUF_Woody_num_freq_K, CUF_Woody_freq_occu_K ),
                       list("Grass", MD_Grass_quant_K,"NA","NA", "NA", "NA", CUF_Grass_num_freq_K, CUF_Grass_freq_occu_K),
                       list("Seed", MD_Seed_quant_K, ET_Seed_quant_K, CUF_Seed_num_freq_K, CUF_Seed_freq_occu_K),
                       list("Root", MD_Root_quant_K,"NA","NA", "NA", "NA", "NA","NA", "NA", "NA" ),
                       list("Plant", "NA","NA", "NA", "NA", ET_Plant_unc_quant_K, "NA","NA", "NA", "NA", "NA","NA", "NA", "NA"),
                       list("Carrion", "NA","NA", "NA", "NA", ET_Carrion_quant_K,CUF_Carrion_num_freq_K, CUF_Carrion_freq_occu_K),
                       list("Other", MD_Other_quant_K, "NA","NA", "NA", "NA", "NA","NA", "NA", "NA", "NA","NA", "NA", "NA" ))

colnames(Table_2_results)<-c("Food category","MD_sample_size", "MD_K", "MD_P0", "MD_P1","ET_sample_size", "ET_K", "ET_P0", "ET_P1","CUF_num_sample_size", "CUF_num_K", "CUF_num_P0", "CUF_num_P1","CUF_freq_sample_size", "CUF_freq_K", "CUF_freq_P0", "CUF_freq_P1")

####################################################################################################################################
##TESTING THE EFFECT OF POLYTOMIES IN THE RESULTS####
####################################################################################################################################
## REPRODUCES RESULTS FOR TABLE S2

## Code based on code written by Nathan Kraft- nkraft@biodiversity.ubc.ca
## available at http://www.esapubs.org/archive/ecol/E093/023/thin_terminal_polytomies.R
## presented in publication "T. Jonathan Davies, Nathan J. B. Kraft, Nicolas Salamin, and Elizabeth M. Wolkovich 2012. Incompletely resolved phylogenetic trees inflate estimates of phylogenetic conservatism. Ecology 93:242-247. http://dx.doi.org/10.1890/11-1360.1"

## R-function to identify terminal polytomies, then randomly thin those 
## polytomies until only 'keep' number of taxa remain in each polytomy.
## Designed to work on an object of class "phylo" as defined in the R-
## package, ape (Paradis et al. 2004 ).

thin_terminal_polytomies=function(phy, keep=2){
  require(ape)
  phy$edge->edges
  length(phy$tip.label)->ntips
  edges[which(edges[,2]<=ntips),]->terminal_edges
  if(sum(table(terminal_edges[,1])>2)==0){
    print("no polytomies- returning original tree")
    return(phy)
  }
  names(which(table(terminal_edges[,1])>2))->poly_list
  droplist<-NULL
  for(i in 1:length(poly_list)){
    terminal_edges[which(terminal_edges[,1]==poly_list[i]),2]->tips
    droplist<-c(droplist, sample(tips, size=(length(tips)-keep)))
  }
  drop.tip(phy, droplist)->phy_thin
  return(phy_thin)
}

library(caper)
tree=read.nexus("Fritz_tree.nex") 

##function to estima effect of polytomies and if interested also P1 values associated with simulating Brownian motion in the thinned trees.
##Please note that estimating P1 for all thinned trees can be a computationally long proccess, also default simulation values especially bounds may need to be changed for certain traits
##Output may be summary data from the multiple trees or the results from each tree

politomies_effects<-function(data_subset, trait, N_datasets,log=FALSE, FullRes=FALSE, P1_estimate=FALSE, N_sim=1000, bounds_sim=c(-Inf, Inf)){
  row.names(data_subset)=data_subset$binomial_tree
  test1=as.vector(as.matrix(subset(data_subset, select=trait)))
  if (log==TRUE){
    print("log-transformed variable")
    test1<-log10(test1)
    }
  names(test1)=row.names(data_subset)
  results<-matrix(nrow=N_datasets, ncol=3)
  resultsP1<-matrix(nrow=N_datasets, ncol=4)
  for (i in 1:N_datasets){
    treK_t<-thin_terminal_polytomies(tree)  
    sss<-which(names(data_subset)==trait)
    selection<-subset(data_subset, data_subset[,sss]>-1)
    C1 <- comparative.data(phy = treK_t, data = selection, names.col = binomial_tree, na.omit=F)
    kappa<-phylosig(C1$phy, test1, method="K",test=T) 
    results[[i,1]]<-c(nrow(C1$data))
    results[[i,2]]<-c(kappa$K)
    results[[i,3]]<-c(kappa$P)
    if (P1_estimate==TRUE){
      print("Estimating P1 - simulating Brownian evolution")
      tree1 <- multi2di(C1$phy, random = TRUE)  
      ss<-which(names(C1$data)==trait)
      if (log==TRUE){
        print("log-transformed variable")
        nullK<-apply(fastBM(C1$phy, n=N_sim, sig2=mean(pic(log10(C1$data[,ss]),C1$phy)^2), a=mean(log10(C1$data[,ss])), bounds=bounds_sim),2, phylosig,tree=C1$phy)
      }
      nullK<-apply(fastBM(tree1, n=N_sim, sig2=mean(pic(C1$data[,ss],tree1)^2), a=mean(C1$data[,ss]), bounds=bounds_sim),2, phylosig,tree=tree1)
    }
    resultsP1[[i,1]]<-c(nrow(C1$data))
    resultsP1[[i,2]]<-c(kappa$K)
    resultsP1[[i,3]]<-c(kappa$P)
    resultsP1[[i,4]]<-c(round(mean(abs(log(c(kappa$K,nullK)))>=abs(log(kappa$K))),digits=5))
    
  }
  if (P1_estimate==TRUE){
    if (FullRes==TRUE){ return(resultsP1)}
    return(c(round(min(resultsP1[,1]), digits=0),round(max(resultsP1[,1]), digits=0),round(mean(resultsP1[,2]), digits=3),round(min(results[,2]), digits=3),round(max(results[,2]), digits=3),round((sum(resultsP1[,3]<0.05)/nrow(resultsP1)), digits=3),round((sum(resultsP1[,4]<0.05)/nrow(resultsP1)), digits=3)))
  }
  else {
    if (FullRes==TRUE){ return(results)}
    return(c(round(min(results[,1]), digits=0),round(max(results[,1]), digits=0),round(mean(results[,2]), digits=3),round(min(results[,2]), digits=3),round(max(results[,2]), digits=3),round((sum(results[,3]<0.05)/nrow(results)), digits=3)))
  }
}

MD_res_pol_Diet<-politomies_effects(MammalDIET_sub, "MD_Diet_breadth" , 100, P1_estimate = FALSE, N_sim=1000, bounds_sim=c(1,12))
MD_res_pol_ges<-politomies_effects(MammalDIET_sub, "Gestation_length_days" ,log=TRUE,  100, P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
MD_res_pol_mass<-politomies_effects(MammalDIET_sub, "Adult_body_mass_g" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
MD_res_pol_home<-politomies_effects(MammalDIET_sub, "Home_range_size_km2" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(-Inf,Inf))
MD_res_pol_group<-politomies_effects(MammalDIET_sub, "Group_size_ind" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
MD_res_pol_dist<-politomies_effects(MammalDIET_sub, "Distribution_range_area_km2" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))

MD_pol<-rbind(MD_res_pol_ges, MD_res_pol_mass, MD_res_pol_home,MD_res_pol_group, MD_res_pol_dist, MD_res_pol_Diet, c("NA", "NA", "NA","NA","NA", "NA"))

ET_res_pol_Diet<-politomies_effects(EltonTraits_sub, "ET_Diet_breadth" , 100, P1_estimate = FALSE, N_sim=1000, bounds_sim=c(1,10))
ET_res_pol_Levins<-politomies_effects(EltonTraits_sub, "ET_Levins_stand" , 10, P1_estimate = TRUE, N_sim=1000, bounds_sim=c(0,100))
ET_res_pol_ges<-politomies_effects(EltonTraits_sub, "Gestation_length_days" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
ET_res_pol_mass<-politomies_effects(EltonTraits_sub, "Adult_body_mass_g" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
ET_res_pol_home<-politomies_effects(EltonTraits_sub, "Home_range_size_km2" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(-Inf,Inf))
ET_res_pol_group<-politomies_effects(EltonTraits_sub, "Group_size_ind" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
ET_res_pol_dist<-politomies_effects(EltonTraits_sub, "Distribution_range_area_km2" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))

ET_pol<-rbind(ET_res_pol_ges, ET_res_pol_mass, ET_res_pol_home,ET_res_pol_group, ET_res_pol_dist, ET_res_pol_Diet, ET_res_pol_Levins)

CUF_res_pol_Diet<-politomies_effects(CUFdiet_sub, "CUF_Diet_breadth" , 100, P1_estimate = FALSE, N_sim=1000, bounds_sim=c(1,12))
CUF_res_pol_Levins<-politomies_effects(CUFdiet_sub, "CUF_Levins_stand" , 100, P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,1))
CUF_res_pol_ges<-politomies_effects(CUFdiet_sub, "Gestation_length_days" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
CUF_res_pol_mass<-politomies_effects(CUFdiet_sub, "Adult_body_mass_g" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
CUF_res_pol_home<-politomies_effects(CUFdiet_sub, "Home_range_size_km2" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(-Inf,Inf))
CUF_res_pol_group<-politomies_effects(CUFdiet_sub, "Group_size_ind" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))
CUF_res_pol_dist<-politomies_effects(CUFdiet_sub, "Distribution_range_area_km2" ,100, log=TRUE,  P1_estimate = FALSE, N_sim=1000, bounds_sim=c(0,Inf))

CUF_pol<-rbind(CUF_res_pol_ges, CUF_res_pol_mass, CUF_res_pol_home,CUF_res_pol_group, CUF_res_pol_dist, CUF_res_pol_Diet, CUF_res_pol_Levins)


##Generating Table S2
Table_S2_results<-cbind(MD_pol, ET_pol, CUF_pol)
colnames(Table_S2_results)<-c("MD_min_N", "MD_max_N","MD_mean_K", "MD_min_K", "MD_max_K","MD_P0", 
                              "ET_min_N", "ET_max_N","ET_mean_K", "ET_min_K", "ET_max_K", "ET_P0", 
                              "CUF_min_N", "CUF_max_N","CUF_mean_K", "CUF_min_K", "CUF_max_K","CUF_P0")


####################################################################################################################################
##ESTIMATING THE NET RELATEDNESS INDEX####
####################################################################################################################################

library(ape)
library(PhyloMeasures)
library(caper)

##generate a database all species in the phylogeny with 0 indicating no data in the diet database and 1 indicating data available. Please note that because in the original dataset species that have no data for either global database were excluded we generated a new dataset with 5020 species (those in the phylogeny), as a result some species have zero for both MammalDIET and EltonTraits

diet_availability<-merge(as.data.frame(tree$tip.label),(data[,c("binomial_tree","MammalDIET", "EltonTraits")]), by.x="tree$tip.label", by.y="binomial_tree", all=T)
diet_availability[is.na(diet_availability)]<-0
colnames(diet_availability)<-c("binomial", "MammalDIET", "EltonTraits")

spp_matrix<-as.matrix(t(diet_availability[,2:3]))
colnames(spp_matrix) <- diet_availability$binomial

#### MPD #### (NRI) Phylogenetic structure
#get the standardized MPD values, NRI=-MPD
spp.mpd <- mpd.query(tree,spp_matrix,TRUE)
spp.mpd
#check the result by using permutations as implemented in Picante's functions
library(picante)
spp.ses.mpd<-ses.mpd(samp = spp_matrix,dis=cophenetic(tree),null.model = "taxa.labels")
spp.ses.mpd
